Package: shinyMobile
Type: Package
Title: Mobile Ready 'shiny' Apps with Standalone Capabilities
Version: 2.0.1
Authors@R: c(
  person("David", "Granjon", email = "dgranjon@ymail.com", role = c("aut", "cre")),
  person("Veerle", "van Leemput", email = "veerle@hypebright.nl", role = "aut"),
  person("AthlyticZ", role = "fnd"),
  person("Victor", "Perrier", email = "info@dreamrs.fr", role = "aut"),
  person("John", "Coene", email = "jcoenep@gmail.com", role = "ctb"),
  person("Isabelle", "Rudolf", email = "", role = "aut"),
  person("Dieter", "Menne", email = "dieter.menne@menne-biomed.de", role = "ctb"),
  person(family = "Marvelapp", role = c("ctb", "cph"), comment = "device.css wrappers"),
  person("Vladimir", "Kharlampidi", email = "nolimits4web@gmail.com", role = c("ctb", "cph"), comment = "Framework7 HTML template"))
Maintainer: David Granjon <dgranjon@ymail.com>
Description: Develop outstanding 'shiny' apps for 'iOS' and 'Android' as well as beautiful 'shiny' gadgets.
    'shinyMobile' is built on top of the latest 'Framework7' template <https://framework7.io>.
    Discover 14 new input widgets (sliders, vertical sliders, stepper, 
    grouped action buttons, toggles, picker, smart select, ...), 2 themes (light and dark), 
    12 new widgets (expandable cards, badges, chips, timelines, gauges, progress bars, ...) 
    combined with the power of server-side notifications such as alerts, modals, toasts,
    action sheets, sheets (and more) as well as 3 layouts (single, tabs and split).
Imports: shiny, htmltools, jsonlite, magrittr, gplots, lifecycle
License: GPL-2
Encoding: UTF-8
URL: https://github.com/RinteRface/shinyMobile,
        https://rinterface.github.io/shinyMobile/
BugReports: https://github.com/RinteRface/shinyMobile/issues
RoxygenNote: 7.3.2
Suggests: knitr, rmarkdown, stats, cli, testthat (>= 2.1.0),
        rstudioapi, shinyWidgets, apexcharter, ggplot2, dplyr, bslib,
        shinytest2, thematic
VignetteBuilder: knitr
Config/testthat/parallel: true
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-10-04 15:53:32 UTC; davidgranjon
Author: David Granjon [aut, cre],
  Veerle van Leemput [aut],
  AthlyticZ [fnd],
  Victor Perrier [aut],
  John Coene [ctb],
  Isabelle Rudolf [aut],
  Dieter Menne [ctb],
  Marvelapp [ctb, cph] (device.css wrappers),
  Vladimir Kharlampidi [ctb, cph] (Framework7 HTML template)
Repository: CRAN
Date/Publication: 2024-10-04 17:30:02 UTC
Built: R 4.6.0; ; 2026-04-28 18:57:01 UTC; unix
